from .amps.label           import AmpsLabel
from .amps.line_edit       import AmpsLineEdit
from .db.label             import dBLabel
from .db.line_edit         import dBLineEdit
from .dbm.label            import dBmLabel
from .dbm.line_edit        import dBmLineEdit
from .file                 import FileWidget
from .hz.label             import HzLabel
from .hz.line_edit         import HzLineEdit
from .ip_address.line_edit import IPAddressLineEdit
from .meters.label         import MetersLabel
from .meters.line_edit     import MetersLineEdit
from .ohms.label           import OhmsLabel
from .ohms.line_edit       import OhmsLineEdit
from .touchstone           import TouchstoneWidget
from .value.label          import ValueLabel
from .value.line_edit      import ValueLineEdit
from .volts.label          import VoltsLabel
from .volts.line_edit      import VoltsLineEdit



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'designer/filewidget.ui',
# licensing of 'designer/filewidget.ui' applies.
#
# Created: Mon Apr  1 22:51:43 2019
#      by: pyside2-uic  running on PySide2 5.12.2
#
# WARNING! All changes made in this file will be lost!

from PySide2 import QtCore, QtGui, QtWidgets

class Ui_FileWidget(object):
    def setupUi(self, FileWidget):
        FileWidget.setObjectName("FileWidget")
        FileWidget.resize(133, 33)
        self.horizontalLayout = QtWidgets.QHBoxLayout(FileWidget)
        self.horizontalLayout.setSpacing(-1)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.filename = QtWidgets.QLineEdit(FileWidget)
        self.filename.setReadOnly(True)
        self.filename.setObjectName("filename")
        self.horizontalLayout.addWidget(self.filename)
        self.button = QtWidgets.QPushButton(FileWidget)
        self.button.setObjectName("button")
        self.horizontalLayout.addWidget(self.button)

        self.retranslateUi(FileWidget)
        QtCore.QMetaObject.connectSlotsByName(FileWidget)

    def retranslateUi(self, FileWidget):
        self.button.setText(QtWidgets.QApplication.translate("FileWidget", "...", None, -1))





from PySide2.QtCore    import QRegExp
from PySide2.QtGui     import QRegExpValidator
from PySide2.QtWidgets import QLineEdit

from_zero = r'(((00)?\d)|([01]?\d\d)|(2[0-4]\d)|(25[0-5]))'
from_one  = r'(((0|00)?[1-9])|(0?[1-9]\d)|(1\d\d)|(2[0-4]\d)|(25[0-5]))'
dot       = r'\.'
regex_str = '{from_one}{dot}{from_zero}{dot}{from_zero}{dot}{from_one}'.format(from_zero=from_zero, from_one=from_one, dot=dot)

class IPAddressLineEdit(QLineEdit):
    def __init__(self, parent=None):
        QLineEdit.__init__(self, parent)
        validator = QRegExpValidator(QRegExp(regex_str))
        self.setValidator(validator)
    def focusInEvent(self, event):
        self.selectAll()



from .ui_filewidget             import Ui_FileWidget
from pathlib                    import Path
from PySide2.QtCore             import Slot
from PySide2.QtWidgets          import QFileDialog, QWidget

class FileWidget(QWidget):
    def __init__(self, parent=None):
        QWidget.__init__(self, parent)
        self.ui = Ui_FileWidget()
        self.ui.setupUi(self)
        self.caption   = 'Open...'
        self.filter    = ''
        self._filename = None

    @property
    def filename(self):
        return self._filename
    @filename.setter
    def filename(self, value):
        self._filename = value
        self.update_filename()

    def _dir(self):
        if self.filename:
            return str(Path(self.filename).parent)
        else:
            return ''

    @Slot()
    def on_button_clicked(self):
        filename, filter = QFileDialog.getOpenFileName(self.window(), self.caption, self._dir(), self.filter)
        if filename:
            self.filename = filename

    def update_filename(self):
        if self._filename:
            self.ui.filename.setText(Path(self._filename).name)
        else:
            self.ui.filename.clear()



from PySide2.QtWidgets import QLabel
from qtrf.mixins.value import ValueMixin

class ValueLabel(ValueMixin, QLabel):
    def __init__(self, parent=None):
        QLabel    .__init__(self, parent)
        ValueMixin.__init__(self)
